@@ -36,7 +36,9 @@ class CoreDriver(brt.TypicalApplication):
 		yy.token('TEXT', AST.Constant('\n', yy.current_span(), 'TEXT'))
 		
 	def scan_letter_escape(self, yy:Scanner):
-		yy.token('TEXT', chr(7+'abtnvfr'.index(yy.matched_text())))
+		letter = yy.matched_text()[1]
+		codepoint = 7+'abtnvfr'.index(letter)
+		yy.token('TEXT', AST.Constant(chr(codepoint), yy.current_span(), 'TEXT'))
 	
 	def scan_token(self, yy:Scanner, kind):
 		# Concrete tokens that won't contribute to the AST
@@ -139,6 +141,7 @@ class CoreDriver(brt.TypicalApplication):
 		return formulae.LiteralText(text.value)
 	def parse_tpl_plaintext(self, name:AST.Name): return formulae.PlainOrdinal(name.text)
 	def parse_tpl_raw(self, name:AST.Name): return formulae.RawOrdinal(name.text)
+	def parse_quote_label(self, label:formulae.Label): return formulae.Quotation(label)
 	def parse_select_set(self, fields:List[AST.Name]) -> formulae.Predicate:
 		if len(fields) == 1: return formulae.IsEqual(fields[0].text)
 		else: return formulae.IsInSet(frozenset(f.text for f in fields))
